@@ -881,56 +881,3 @@ gnome_print_encode_deflate (const guchar *in, guchar *out, gint in_size, gint ou
 	return c_stream.total_out;
 }
 	
-
-
-
-
-
-
-
-
-
-
-#if 0 /* Disabled by chema 20.oct.2000 -*/
-/* GnomePrintEncode virtual stopwatch */
-#include <time.h>
-
-typedef struct {
-	clock_t begin_clock, save_clock;
-	time_t  begin_time, save_time;
-} time_keeper;
-
-static time_keeper tk;
-
-void
-gnome_print_encode_timer_start (void)
-{
-	tk.begin_clock = tk.save_clock = clock ();
-	tk.begin_time = tk.save_time = time (NULL);
-}
-
-#define MAX_TIME_STRING 100
-#include <stdio.h>
-void
-gnome_print_encode_timer_end (void)
-{
-	gchar s1 [MAX_TIME_STRING], s2 [MAX_TIME_STRING];
-	gint  field_width, n1, n2;
-	gdouble clocks_per_second = (double) CLOCKS_PER_SEC, user_time, real_time;
-
-	user_time = (clock() - tk.save_clock) / clocks_per_second;
-	real_time = difftime (time (NULL), tk.save_time);
-	tk.save_clock = clock ();
-	tk.save_time = time (NULL);
-
-	/* print the values ... */
-	n1 = sprintf (s1, "%.5f", user_time);
-	n2 = sprintf (s2, "%.5f", real_time);
-	field_width = (n1 > n2)?n1:n2;
-	g_print ("%s%*.5f%s\n%s%*.5f%s\n\n",
-		 "User time : ", field_width, user_time, " seconds",
-		 "Real time : ", field_width, real_time, " seconds");
-}
-
-
-#endif
