@@ -109,7 +109,10 @@ struct _GRFGlyphSlot {
 #define GRF_COORD_FROM_FLOAT_LOWER(f) ((gint) floor (f * 64.0))
 #define GRF_COORD_FROM_FLOAT_UPPER(f) ((gint) ceil (f * 64.0))
 
-#define GRF_NUM_GLYPHS(f) ((f)->font->face->num_glyphs)
+static inline gint gnome_rfont_get_num_glyphs (GnomeRFont *rfont);
+
+#define GRF_NUM_GLYPHS(f) (gnome_rfont_get_num_glyphs (f))
+#define G__RF_NUM_GLYPHS(f) ((f)->font->face->num_glyphs)
 #define GRF_FT_FACE(f) ((f)->font->face->ft_face)
 #define FT_MATRIX_IS_IDENTITY(f) (((f)->matrix.xx == 0x10000) && ((f)->matrix.yx == 0) && ((f)->matrix.xy == 0) && ((f)->matrix.yy == 0x10000))
 
@@ -185,7 +188,8 @@ gnome_rfont_finalize (GObject * object)
 	if (rfont->glyphs) {
 		gint i;
 		for (i = 0; i < rfont->glen; i++) {
-			if (!rfont->glyphs[i].is_greek && rfont->glyphs[i].bd.px) g_free (rfont->glyphs[i].bd.px);
+			if (!rfont->glyphs[i].is_greek && rfont->glyphs[i].bd.px)
+				g_free (rfont->glyphs[i].bd.px);
 		}
 		g_free (rfont->glyphs);
 	}
@@ -263,7 +267,8 @@ gnome_font_get_rfont (GnomeFont * font, const gdouble *t)
 
 	/* Create index table */
 	rfont->idx = g_new (gint, GRF_NUM_GLYPHS (rfont));
-	for (i = 0; i < GRF_NUM_GLYPHS (rfont); i++) rfont->idx[i] = -1;
+	for (i = 0; i < GRF_NUM_GLYPHS (rfont); i++)
+		rfont->idx[i] = -1;
 
 	PRINT_AFFINE ("RFont matrix:", &t[0]);
 	/* Calculate integer resolutions */
@@ -291,7 +296,8 @@ gnome_font_get_rfont (GnomeFont * font, const gdouble *t)
 	}
 	/* Save values in FT format */
 	rfont->load_glyph_flags = 0;
-	if (FT_MATRIX_IS_IDENTITY (rfont)) rfont->load_glyph_flags |= FT_LOAD_IGNORE_TRANSFORM;
+	if (FT_MATRIX_IS_IDENTITY (rfont))
+		rfont->load_glyph_flags |= FT_LOAD_IGNORE_TRANSFORM;
 	rfont->pixel_width = (FT_UInt) dpixx;
 	rfont->pixel_height = (FT_UInt) dpixy;
 #ifdef GRF_VERBOSE
@@ -301,6 +307,10 @@ gnome_font_get_rfont (GnomeFont * font, const gdouble *t)
 	rfont->vector = ((rfont->pixel_width > GRF_MAX_GLYPH_SIZE) ||
 			 (rfont->pixel_height > GRF_MAX_GLYPH_SIZE) ||
 			 (rfont->pixel_width * rfont->pixel_height > GRF_MAX_GLYPH_AREA));
+#ifdef __GNUC__
+#warning Find the reason for having ->vector, I am setting it to TRUE to fix http://bugzilla.gnome.org/show_bug.cgi?id=81792
+#endif	
+	rfont->vector = TRUE;
 	rfont->greek = ((rfont->pixel_width <= GRF_GREEK_TRESHOLD) ||
 			(rfont->pixel_height <= GRF_GREEK_TRESHOLD));
 	rfont->matrix.xx = (FT_Fixed) floor (dcm[0] * 65536 + 0.5);
@@ -488,10 +498,12 @@ grf_ensure_slot_graymap (GnomeRFont *rfont, gint glyph)
 		slot->has_graymap = TRUE;
 
 		/* No graymap for vector fonts */
-		if (rfont->vector) return slot;
+		if (rfont->vector)
+			return slot;
 
 		/* Do not render glyphs with coverage < 1/64th of pixel */
-		if (((slot->x1 - slot->x0) < 8) || ((slot->y1 - slot->y0) < 8)) return slot;
+		if (((slot->x1 - slot->x0) < 8) || ((slot->y1 - slot->y0) < 8))
+			return slot;
 
 		/* We deliberately allow up to 1 pixel misplacing of greek glyhs */
 		if ((GRF_COORD_INT_UPPER (slot->x1 - slot->x0) * GRF_COORD_INT_UPPER (slot->y1 - slot->y0)) <= GRF_GLYPH_GREEK_TRESHOLD) {
@@ -503,7 +515,8 @@ grf_ensure_slot_graymap (GnomeRFont *rfont, gint glyph)
 			g_return_val_if_fail (status == FT_Err_Ok, slot);
 			status = FT_Get_Glyph (GRF_FT_FACE (rfont)->glyph, (FT_Glyph *) &bm);
 			g_return_val_if_fail (status == FT_Err_Ok, slot);
-			if (((FT_OutlineGlyph) bm)->outline.n_points < 3) return slot;
+			if (((FT_OutlineGlyph) bm)->outline.n_points < 3)
+				return slot;
 			status = FT_Glyph_To_Bitmap ((FT_Glyph *) &bm, ft_render_mode_normal, 0, 1);
 			g_return_val_if_fail (status == FT_Err_Ok, slot);
 
@@ -541,7 +554,8 @@ grf_ensure_slot_graymap (GnomeRFont *rfont, gint glyph)
 		g_return_val_if_fail (status == FT_Err_Ok, slot);
 		status = FT_Get_Glyph (GRF_FT_FACE (rfont)->glyph, (FT_Glyph *) &bm);
 		g_return_val_if_fail (status == FT_Err_Ok, slot);
-		if (((FT_OutlineGlyph) bm)->outline.n_points < 3) return slot;
+		if (((FT_OutlineGlyph) bm)->outline.n_points < 3)
+			return slot;
 		status = FT_Glyph_To_Bitmap ((FT_Glyph *) &bm, ft_render_mode_normal, 0, 1);
 		g_return_val_if_fail (status == FT_Err_Ok, slot);
 
@@ -641,7 +655,8 @@ gnome_rfont_get_glyph_bpath (GnomeRFont * rfont, gint glyph)
 
 	bpath = g_hash_table_lookup (rfont->bpaths, GINT_TO_POINTER (glyph));
 
-	if (bpath) return bpath;
+	if (bpath)
+		return bpath;
 
 	size = gnome_font_get_size (rfont->font);
 	affine[0] = rfont->transform[0] * size * 0.001;
@@ -744,7 +759,8 @@ gnome_rfont_render_glyph_rgba8 (GnomeRFont *rfont, gint glyph,
 
 	slot = grf_ensure_slot_graymap (rfont, glyph);
 	g_return_if_fail (slot && slot->has_graymap);
-	if (slot->is_greek || !slot->bd.px) return;
+	if (slot->is_greek || !slot->bd.px)
+		return;
 
 	xp = (gint) floor (x + 0.5);
 	yp = (gint) floor (y + 0.5);
@@ -793,11 +809,11 @@ gnome_rfont_render_glyph_rgba8 (GnomeRFont *rfont, gint glyph,
 
 void
 gnome_rfont_render_glyph_rgb8 (GnomeRFont *rfont, gint glyph,
-				guint32 rgba,
-				gdouble px, gdouble py,
-				guchar *buf,
-				gint width, gint height, gint rowstride,
-				guint flags)
+			       guint32 rgba,
+			       gdouble px, gdouble py,
+			       guchar *buf,
+			       gint width, gint height, gint rowstride,
+			       guint flags)
 {
 	GRFGlyphSlot *slot;
 	gint x, y, x0, y0, x1, y1, gmw, gmh;
@@ -870,7 +886,8 @@ gnome_rfont_render_glyph_rgb8 (GnomeRFont *rfont, gint glyph,
 		return;
 	}
 
-	if (!slot->bd.px) return;
+	if (!slot->bd.px)
+		return;
 
 	x0 = MAX (0, x + GRF_COORD_INT_LOWER (slot->x0));
 	y0 = MAX (0, y + GRF_COORD_INT_LOWER (slot->y0));
@@ -986,8 +1003,19 @@ rfont_equal (gconstpointer key1, gconstpointer key2)
 	f1 = (GnomeRFont *) key1;
 	f2 = (GnomeRFont *) key2;
 
-	if (f1->font != f2->font) return FALSE;
+	if (f1->font != f2->font)
+		return FALSE;
 
 	return art_affine_equal (f1->transform, f2->transform);
 }
 
+static inline gint
+gnome_rfont_get_num_glyphs (GnomeRFont *rfont)
+{
+	if (!GFF_LOADED (rfont->font->face)) {
+		g_warning ("file %s: line %d: Face %s: Cannot load face",
+			   __FILE__, __LINE__, rfont->font->face->entry->name);
+		return 0;
+	}
+	return rfont->font->face->num_glyphs;
+}
