@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  gnome-font-compat.c: Compatibility functions for font classes
+ *  gp-gc.c: An opaque object, holding current drawing state
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public License
@@ -50,9 +50,9 @@
 #include <libart_lgpl/art_vpath_svp.h>
 #include <libart_lgpl/art_svp_vpath_stroke.h>
 
-#include "gnome-font-compat.h"
 #include "gp-path.h"
 #include "gp-gc.h"
+#include "gp-gc-private.h"
 
 #define GP_GC_EPSILON 1e-18
 #define GP_GC_EQ(a,b) (fabs (a - b) < GP_GC_EPSILON)
