@@ -135,10 +135,14 @@ gpa_media_load (void)
 							gpa_option_list_append_child (GPA_OPTION_LIST (physicalsizes), GPA_OPTION (item));
 							gpa_node_unref (item);
 						}
-						if (id) xmlFree (id);
-						if (width) xmlFree (width);
-						if (height) xmlFree (height);
-						if (name) xmlFree (name);
+						if (id)
+							xmlFree (id);
+						if (width)
+							xmlFree (width);
+						if (height)
+							xmlFree (height);
+						if (name)
+							xmlFree (name);
 					}
 				}
 			} else if (!strcmp (child->name, "PhysicalOrientations")) {
