@@ -134,7 +134,8 @@ gpa_model_finalize (GObject *object)
 		g_hash_table_remove (modeldict, GPA_NODE_ID (model));
 	}
 
-	if (model->vendorid) g_free (model->vendorid);
+	if (model->vendorid)
+		g_free (model->vendorid);
 
 	model->name = gpa_node_detach_unref (GPA_NODE (model), GPA_NODE (model->name));
 	if (model->vendor) {
@@ -156,13 +157,19 @@ gpa_model_verify (GPANode *node)
 
 	model = GPA_MODEL (node);
 
-	if (!model->name) return FALSE;
-	if (!gpa_node_verify (model->name)) return FALSE;
+	if (!model->name)
+		return FALSE;
+	if (!gpa_node_verify (model->name))
+		return FALSE;
 	if (model->loaded) {
-		if (!model->vendorid) return FALSE;
-		if (model->vendor && !gpa_node_verify (model->vendor)) return FALSE;
-		if (!model->options) return FALSE;
-		if (!gpa_node_verify (GPA_NODE (model->options))) return FALSE;
+		if (!model->vendorid)
+			return FALSE;
+		if (model->vendor && !gpa_node_verify (model->vendor))
+			return FALSE;
+		if (!model->options)
+			return FALSE;
+		if (!gpa_node_verify (GPA_NODE (model->options)))
+			return FALSE;
 	}
 
 	return TRUE;
@@ -220,9 +227,11 @@ gpa_model_lookup (GPANode *node, const guchar *path)
 
 	child = NULL;
 
-	if (gpa_node_lookup_ref (&child, GPA_NODE (model->name), path, "Name")) return child;
+	if (gpa_node_lookup_ref (&child, GPA_NODE (model->name), path, "Name"))
+		return child;
 	if (model->vendor) {
-		if (gpa_node_lookup_ref (&child, GPA_NODE (model->vendor), path, "Vendor")) return child;
+		if (gpa_node_lookup_ref (&child, GPA_NODE (model->vendor), path, "Vendor"))
+			return child;
 	} else if (model->vendorid) {
 		subpath = gpa_node_lookup_check (path, "Vendor");
 		if (subpath) {
@@ -291,7 +300,8 @@ gpa_model_new_from_info_tree (xmlNodePtr tree)
 	}
 	g_free (filename);
 
-	if (!modeldict) modeldict = g_hash_table_new (g_str_hash, g_str_equal);
+	if (!modeldict)
+		modeldict = g_hash_table_new (g_str_hash, g_str_equal);
 	model = g_hash_table_lookup (modeldict, xmlid);
 	if (model != NULL) {
 		gpa_node_ref (GPA_NODE (model));
@@ -407,9 +417,12 @@ gpa_model_new_from_tree (xmlNodePtr tree)
 		if (!options) {
 			g_warning ("file %s: line %d: Model does not have valid options", __FILE__, __LINE__);
 		}
-		if (name) gpa_node_unref (name);
-		if (vendor) gpa_node_unref (vendor);
-		if (options) gpa_node_unref (GPA_NODE (options));
+		if (name)
+			gpa_node_unref (name);
+		if (vendor)
+			gpa_node_unref (vendor);
+		if (options)
+			gpa_node_unref (GPA_NODE (options));
 	}
 
 	xmlFree (xmlid);
@@ -433,7 +446,8 @@ gpa_model_list_new_from_info_tree (xmlNodePtr tree)
 		if (!strcmp (xmlc->name, "Model")) {
 			GPANode *model;
 			model = gpa_model_new_from_info_tree (xmlc);
-			if (model) l = g_slist_prepend (l, model);
+			if (model)
+				l = g_slist_prepend (l, model);
 		}
 	}
 
@@ -463,7 +477,8 @@ gpa_model_get_by_id (const guchar *id)
 	g_return_val_if_fail (id != NULL, NULL);
 	g_return_val_if_fail (*id != '\0', NULL);
 
-	if (!modeldict) modeldict = g_hash_table_new (g_str_hash, g_str_equal);
+	if (!modeldict)
+		modeldict = g_hash_table_new (g_str_hash, g_str_equal);
 	model = g_hash_table_lookup (modeldict, id);
 	if (model) {
 		gpa_node_ref (GPA_NODE (model));
